@@ -5,13 +5,14 @@ from time import time
 import logging
 import json
 
-class Recommender(object):
+class Recommender():
     """
     Cold Start Recommender
     """
     def __init__(self, mongo_host=None, mongo_db_name=None, mongo_replica_set=None,
                  default_rating=3, max_rating=5,
-                 log_level=logging.ERROR):
+                 log_level=logging.DEBUG):
+
         if mongo_host is not None:
             assert (mongo_db_name != None)
             if mongo_replica_set is not None:
@@ -58,15 +59,16 @@ class Recommender(object):
         self.items_by_popularity_updated = 0.0  # Time of update
         # Loggin stuff
         self.logger = logging.getLogger("csrc")
-        self.logger.setLevel(logging.DEBUG)
+        self.logger.setLevel(log_level)
+        ch = logging.StreamHandler()
+        ch.setLevel(logging.DEBUG)
+        self.logger.addHandler(ch)
         self.logger.debug("============ Creating a Recommender Instance ================")
         if mongo_host is not None:
             self.logger.debug("============ Host: %s", str(mongo_host))
             if mongo_replica_set is not None:
                 self.logger.debug("============ Replica: %s", str(mongo_replica_set))
 
-
-
     def _coll_name(self, k, typ):
         """
         e.g. user_author_ratings
@@ -143,8 +145,6 @@ class Recommender(object):
                                     upsert=True
                                 )
 
-
-
     def insert_item(self, item, _id="_id"):
         """
         Insert the whole document either in self.items or in db.items.
@@ -162,7 +162,6 @@ class Recommender(object):
                                             {"$set": {k: v}},
                                             upsert=True)
 
-
     def reconcile_ids(self, id_old, id_new):
         """
         Create id_new if not there, add data of id_old into id_new.
@@ -268,8 +267,10 @@ class Recommender(object):
         As per name, get self.
         :return: list of popular items, 0=most popular
         """
-        if fast and (time() - self.most_popular_items_updated) < 3600:
+        if fast and (time() - self.items_by_popularity_updated) < 1800:
             return self.items_by_popularity
+        else:
+            self.items_by_popularity_updated = time()
 
         if not self.db:
             df_item = pd.DataFrame(self.item_ratings).fillna(0).astype(int).sum()
@@ -400,8 +401,8 @@ class Recommender(object):
         else:
             # If the item is not stored, we don't have its categories
             # Therefore do categories only if the item is found stored
-            if self.db['items'].find_one({"_id": item_id}):
-                item = self.db['items'].find_one({"_id": item_id})
+            item = self.db['items'].find_one({"_id": item_id})
+            if item:
                 if len(item_info) > 0:
                     self.logger.debug('[insert_rating] Looking for the following info: %s', item_info)
                     for k, v in item.items():
@@ -538,7 +539,7 @@ class Recommender(object):
                 # but the co-occurence matrix has not been updated
                 # therefore the matrix and the user-vector have different
                 # dimension
-                if not fast or (time() - self.cooccurence_updated > 3600):
+                if not fast or (time() - self.cooccurence_updated > 1800):
                     self._create_cooccurence()
                 rec = self._items_cooccurence.T.dot(df_user[user_id])
                 self.logger.debug("[get_recommendations] Rec: %s", rec)
@@ -619,7 +620,6 @@ class Recommender(object):
         else:
             return list(global_rec.index)[:max_recs]
 
-
     def get_user_info(self, user_id):
         """
         Return user's rated items: {'item1': 3, 'item3': 1...}
